@@ -1,12 +1,16 @@
 #[derive(Debug, Clone, PartialEq, Eq, PartialOrd, Ord)]
 pub struct ErrorBox<E: Error> {
-    inner: E
+    inner: E,
 }
 
 impl<E: Error> ErrorBox<E> {
     pub fn new<S: AsRef<str>>(msg: S) -> Self {
         ErrorBox { inner: E::new(msg) }
     }
+
+    pub fn get(&self) -> &E {
+        &self.inner
+    }
 }
 
 impl<E: Error> ToString for ErrorBox<E> {
@@ -17,7 +21,9 @@ impl<E: Error> ToString for ErrorBox<E> {
 
 impl<E: Error> From<&E> for ErrorBox<E> {
     fn from(err: &E) -> Self {
-        ErrorBox { inner: E::new(err.to_string()) }
+        ErrorBox {
+            inner: E::new(err.to_string()),
+        }
     }
 }
 
